==> jc-1.4.0.tar.gz: java/rmi/server/RMISocketFactory.h <==
// public abstract class java.rmi.server.RMISocketFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ef0c14a2320dd9c java_rmi_server_RMISocketFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_RMISocketFactory_H_
#define _JC_java_rmi_server_RMISocketFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_ServerSocket$object;
struct _jc_java_net_Socket$object;
struct _jc_java_rmi_server_RMIFailureHandler$object;
struct _jc_java_rmi_server_RMISocketFactory$object;

// Typedefs
typedef struct _jc_java_rmi_server_RMISocketFactory$sub_refs	_jc_java_rmi_server_RMISocketFactory$sub_refs;
typedef struct _jc_java_rmi_server_RMISocketFactory$sub_nonrefs	_jc_java_rmi_server_RMISocketFactory$sub_nonrefs;
typedef struct _jc_java_rmi_server_RMISocketFactory$refs	_jc_java_rmi_server_RMISocketFactory$refs;
typedef struct _jc_java_rmi_server_RMISocketFactory$nonrefs	_jc_java_rmi_server_RMISocketFactory$nonrefs;
typedef struct _jc_java_rmi_server_RMISocketFactory$object	_jc_java_rmi_server_RMISocketFactory$object;

typedef struct _jc_java_rmi_server_RMISocketFactory$fields_struct	_jc_java_rmi_server_RMISocketFactory$fields_struct;
typedef const struct _jc_java_rmi_server_RMISocketFactory$vmethods	_jc_java_rmi_server_RMISocketFactory$vmethods;
typedef const struct _jc_java_rmi_server_RMISocketFactory$vtable	_jc_java_rmi_server_RMISocketFactory$vtable;
typedef const struct _jc_java_rmi_server_RMISocketFactory$vtype	_jc_java_rmi_server_RMISocketFactory$vtype;

// Class fields structure
struct _jc_java_rmi_server_RMISocketFactory$fields_struct {
	struct _jc_java_rmi_server_RMISocketFactory$object	*currentFactory;
	struct _jc_object	*currentHandler;
	struct _jc_java_rmi_server_RMISocketFactory$object	*defaultFactory;
};
extern _jc_java_rmi_server_RMISocketFactory$fields_struct _jc_java_rmi_server_RMISocketFactory$class_fields;

// Constructors
extern void _jc_java_rmi_server_RMISocketFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_RMISocketFactory$object *);

// Virtual methods
extern struct _jc_java_net_ServerSocket$object *_jc_java_rmi_server_RMISocketFactory$method$createServerSocket$b3153da56a9db8c5(_jc_env *, struct _jc_java_rmi_server_RMISocketFactory$object *, jint);
extern struct _jc_java_net_Socket$object *_jc_java_rmi_server_RMISocketFactory$method$createSocket$0d93b2802005a3fd(_jc_env *, struct _jc_java_rmi_server_RMISocketFactory$object *, struct _jc_java_lang_String$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_RMISocketFactory$method_info$createServerSocket$b3153da56a9db8c5;
extern _jc_method _jc_java_rmi_server_RMISocketFactory$method_info$createSocket$0d93b2802005a3fd;

// Static methods
extern void _jc_java_rmi_server_RMISocketFactory$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_rmi_server_RMISocketFactory$object *_jc_java_rmi_server_RMISocketFactory$method$getDefaultSocketFactory$f32aa0edb2c078ea(_jc_env *);
extern struct _jc_object *_jc_java_rmi_server_RMISocketFactory$method$getFailureHandler$969eb8a4d5a85a3d(_jc_env *);
extern struct _jc_java_rmi_server_RMISocketFactory$object *_jc_java_rmi_server_RMISocketFactory$method$getSocketFactory$546a7f38a5f0e46f(_jc_env *);
extern void _jc_java_rmi_server_RMISocketFactory$method$setFailureHandler$7d95d5e4d466820b(_jc_env *, struct _jc_object *);
extern void _jc_java_rmi_server_RMISocketFactory$method$setSocketFactory$4c08a120a10d0edb(_jc_env *, struct _jc_java_rmi_server_RMISocketFactory$object *);

// Virtual methods structure
struct _jc_java_rmi_server_RMISocketFactory$vmethods {
	struct _jc_java_net_ServerSocket$object	*(*createServerSocket$b3153da56a9db8c5)(_jc_env *, struct _jc_java_rmi_server_RMISocketFactory$object *, jint);
	struct _jc_java_net_Socket$object	*(*createSocket$0d93b2802005a3fd)(_jc_env *, struct _jc_java_rmi_server_RMISocketFactory$object *, struct _jc_java_lang_String$object *, jint);
};

// Vtable
struct _jc_java_rmi_server_RMISocketFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RMISocketFactory$vmethods	java_rmi_server_RMISocketFactory;
};

// Vtype
struct _jc_java_rmi_server_RMISocketFactory$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RMISocketFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RMISocketFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RMISocketFactory$refs {
    _jc_java_rmi_server_RMISocketFactory$sub_refs	java_rmi_server_RMISocketFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RMISocketFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RMISocketFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RMISocketFactory$sub_nonrefs	java_rmi_server_RMISocketFactory;
};

// Object instance structure
struct _jc_java_rmi_server_RMISocketFactory$object {
	_jc_java_rmi_server_RMISocketFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RMISocketFactory$vtype	*vtype;
	_jc_java_rmi_server_RMISocketFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RMISocketFactory$vtype _jc_java_rmi_server_RMISocketFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RMISocketFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RMISocketFactory$class_object;

#endif	/* _JC_java_rmi_server_RMISocketFactory_H_ */

==> jc-1.4.6.tar.gz: java/rmi/server/RMISocketFactory.h <==
// public abstract class java.rmi.server.RMISocketFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ef0c14a2320dd9c java_rmi_server_RMISocketFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_RMISocketFactory_H_
#define _JC_java_rmi_server_RMISocketFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_ServerSocket$object;
struct _jc_java_net_Socket$object;
struct _jc_java_rmi_server_RMIFailureHandler$object;
struct _jc_java_rmi_server_RMISocketFactory$object;

// Typedefs
typedef struct _jc_java_rmi_server_RMISocketFactory$sub_refs	_jc_java_rmi_server_RMISocketFactory$sub_refs;
typedef struct _jc_java_rmi_server_RMISocketFactory$sub_nonrefs	_jc_java_rmi_server_RMISocketFactory$sub_nonrefs;
typedef struct _jc_java_rmi_server_RMISocketFactory$refs	_jc_java_rmi_server_RMISocketFactory$refs;
typedef struct _jc_java_rmi_server_RMISocketFactory$nonrefs	_jc_java_rmi_server_RMISocketFactory$nonrefs;
typedef struct _jc_java_rmi_server_RMISocketFactory$object	_jc_java_rmi_server_RMISocketFactory$object;

typedef struct _jc_java_rmi_server_RMISocketFactory$fields_struct	_jc_java_rmi_server_RMISocketFactory$fields_struct;
typedef const struct _jc_java_rmi_server_RMISocketFactory$vmethods	_jc_java_rmi_server_RMISocketFactory$vmethods;
typedef const struct _jc_java_rmi_server_RMISocketFactory$vtable	_jc_java_rmi_server_RMISocketFactory$vtable;
typedef const struct _jc_java_rmi_server_RMISocketFactory$vtype	_jc_java_rmi_server_RMISocketFactory$vtype;

// Class fields structure
struct _jc_java_rmi_server_RMISocketFactory$fields_struct {
	struct _jc_java_rmi_server_RMISocketFactory$object	*currentFactory;
	struct _jc_object	*currentHandler;
	struct _jc_java_rmi_server_RMISocketFactory$object	*defaultFactory;
};
extern _jc_java_rmi_server_RMISocketFactory$fields_struct _jc_java_rmi_server_RMISocketFactory$class_fields;

// Constructors
extern void _jc_java_rmi_server_RMISocketFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_RMISocketFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_net_ServerSocket$object *_jc_java_rmi_server_RMISocketFactory$method$createServerSocket$b3153da56a9db8c5(_jc_env *, struct _jc_java_rmi_server_RMISocketFactory$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_net_Socket$object *_jc_java_rmi_server_RMISocketFactory$method$createSocket$0d93b2802005a3fd(_jc_env *, struct _jc_java_rmi_server_RMISocketFactory$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_RMISocketFactory$method_info$createServerSocket$b3153da56a9db8c5;
extern _jc_method _jc_java_rmi_server_RMISocketFactory$method_info$createSocket$0d93b2802005a3fd;

// Static methods
extern void _jc_java_rmi_server_RMISocketFactory$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_rmi_server_RMISocketFactory$object *_jc_java_rmi_server_RMISocketFactory$method$getDefaultSocketFactory$f32aa0edb2c078ea(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_server_RMISocketFactory$method$getFailureHandler$969eb8a4d5a85a3d(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_rmi_server_RMISocketFactory$object *_jc_java_rmi_server_RMISocketFactory$method$getSocketFactory$546a7f38a5f0e46f(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_RMISocketFactory$method$setFailureHandler$7d95d5e4d466820b(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_RMISocketFactory$method$setSocketFactory$4c08a120a10d0edb(_jc_env *, struct _jc_java_rmi_server_RMISocketFactory$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_server_RMISocketFactory$vmethods {
	struct _jc_java_net_ServerSocket$object	*(*createServerSocket$b3153da56a9db8c5)(_jc_env *, struct _jc_java_rmi_server_RMISocketFactory$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_net_Socket$object	*(*createSocket$0d93b2802005a3fd)(_jc_env *, struct _jc_java_rmi_server_RMISocketFactory$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_server_RMISocketFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RMISocketFactory$vmethods	java_rmi_server_RMISocketFactory;
};

// Vtype
struct _jc_java_rmi_server_RMISocketFactory$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RMISocketFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RMISocketFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RMISocketFactory$refs {
    _jc_java_rmi_server_RMISocketFactory$sub_refs	java_rmi_server_RMISocketFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RMISocketFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RMISocketFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RMISocketFactory$sub_nonrefs	java_rmi_server_RMISocketFactory;
};

// Object instance structure
struct _jc_java_rmi_server_RMISocketFactory$object {
	_jc_java_rmi_server_RMISocketFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RMISocketFactory$vtype	*vtype;
	_jc_java_rmi_server_RMISocketFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RMISocketFactory$vtype _jc_java_rmi_server_RMISocketFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RMISocketFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RMISocketFactory$class_object;

#endif	/* _JC_java_rmi_server_RMISocketFactory_H_ */
